@@ -108,13 +108,13 @@ function(x, y, ..., keepnames=FALSE) {
 		projx <- proj4string(x[[1]])
 		for (i in 2:length(x)) {
 			if (is.na(proj4string(x[[i]]))) {
-				crs(x[[i]]) <- proj4string(x[[1]])			
+				x[[i]]@proj4string <- x[[1]]@proj4string			
 			} else if (! identical(projx, proj4string(x[[i]])) ) {
 				if (!haswarned) {
 					warning('non identical CRS')
 					haswarned <- TRUE
 				}
-				crs(x[[i]]) <- proj4string(x[[1]])
+				x[[i]]@proj4string <- x[[1]]@proj4string			
 			}
 		}	
 				
@@ -198,13 +198,13 @@ setMethod('bind', signature(x='SpatialLines', y='SpatialLines'),
 		projx <- proj4string(x[[1]])
 		for (i in 2:length(x)) {
 			if (is.na(proj4string(x[[i]]))) {
-				crs(x[[i]]) <- proj4string(x[[1]])			
+				x[[i]]@proj4string <- x[[1]]@proj4string			
 			} else if (! identical(projx, proj4string(x[[i]])) ) {
 				if (!haswarned) {
 					warning('non identical CRS')
 					haswarned <- TRUE
 				}
-				crs(x[[i]]) <- proj4string(x[[1]])
+				x[[i]]@proj4string <- x[[1]]@proj4string			
 			}
 		}	
 		
