@@ -5,7 +5,7 @@
 
 
 
-.pointBuffer <- function(xy, d, lonlat=TRUE, a=6378137, f=1/298.257223563, crs=NA, ... ) {
+.pointBuffer <- function(xy, d, lonlat=TRUE, a=6378137, f=1/298.257223563, crs="", ... ) {
 	
 	n <- list(...)$quadsegs
 	if (is.null(n)) {
@@ -99,13 +99,13 @@ function(x, width=0, filename='', doEdge=FALSE, ...) {
 		pts <- try(  rasterToPoints(x)[,1:2, drop=FALSE] )
 	}
 	
-	if (class(pts) == "try-error") {
+	if (class(pts)[1] == "try-error") {
 		d <- .distanceRows(x, filename=filename, ...) 
 		d <- reclassify(d, rbind(c(-1,width, 1), c(width, Inf, NA)))
 		return(d)
 	}
 	if (nrow(pts) == 0) {
-		stop('RasterLayer has no NA cells (for which to compute a distance)')
+		stop('RasterLayer has no NA cells for which to compute a distance')
 	}
 	out <- raster(x)
 	filename <- trim(filename)
