@@ -44,18 +44,22 @@ canProcessInMemory <- function(x, n=4, verbose=FALSE) {
 		return(FALSE)
 	}
 
+	nc <- ncell(x)
+	# avoid vectors that are too long
+	
 	n <- n * nlayers(x)
-	memneed <- ncell(x) * n * 8
+	memneed <- nc * n * 8
 	maxmem <- .maxmemory()
 	memavail <- .availableRAM(maxmem)
 	if (verbose) {
 		gb <- 1073741824
-		cat("memory stats in GB")
-		cat(paste("\nmem available:", round(memavail / gb, 2)))
-		cat(paste0("\n        ", round(100*.memfrac()) , "%  : ", round(.memfrac() * memavail / gb, 2)))
-		cat(paste("\nmem needed   :", round(memneed / gb, 2)))
-		cat(paste("\nmax allowed  :", round(maxmem / gb, 2), " (if available)\n"))
+		cat("            GB")
+		cat(paste("\navailable :", round(memavail / gb, 2)))
+		cat(paste0("\n      ", round(100*.memfrac()) , "% : ", round(.memfrac() * memavail / gb, 2)))
+		cat(paste("\n   needed :", round(memneed / gb, 2)))
+		cat(paste("\n  allowed :", round(maxmem / gb, 2), " (if available)\n"))
 	}
+	if (nc > (2^31 -1)) return(FALSE)
 
 	# can't use all of it; default is 60%
 	memavail <- .memfrac() * memavail
