@@ -15,10 +15,10 @@ setMethod('raster', signature(x='missing'),
 				crs <- CRS("+proj=longlat +datum=WGS84")
 			} else {
 				# if sp >= 1.2.1  crs <- CRS(as.character(NA), doCheckCRSArgs=FALSE)
-				crs <- CRS(as.character(NA))
+				crs <- CRS(as.character(NA), doCheckCRSArgs=FALSE)
 			}
 		} else {
-			crs <- CRS(as.character(projection(crs)))
+			crs <- .getCRS(crs)
 		}
 		if (missing(resolution)) {
 			nrows <- as.integer(max(1, round(nrows)))
@@ -66,12 +66,13 @@ setMethod('raster', signature(x='list'),
 		
 		if (missing(crs)) {
 			if (xmn > -360.1 & xmx < 360.1 & ymn > -90.1 & ymx < 90.1) { 
-				crs <- "+proj=longlat +datum=WGS84"
+				crs <- CRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- as.character(NA)
+				crs <- CRS(as.character(NA))
 			}
-		} 
-		
+		} else {
+			crs <- .getCRS(crs)
+		}
 		x <- t(x$z)
 		x <- x[nrow(x):1, ]
 		r <- raster( x, xmn=xmn, xmx=xmx, ymn=ymn, ymx=ymx, crs=crs )
@@ -82,10 +83,8 @@ setMethod('raster', signature(x='list'),
 
 
 setMethod('raster', signature(x='matrix'), 
-	function(x, xmn=0, xmx=1, ymn=0, ymx=1, crs=NA, template=NULL) {
-		if (isTRUE(is.na(crs))) {
-			crs <- as.character(NA)
-		}	
+	function(x, xmn=0, xmx=1, ymn=0, ymx=1, crs="", template=NULL) {
+		crs <- .getCRS(crs)
 		if (!is.null(template)) {
 			if (inherits(template, 'Extent')) {
 				r <- raster(template, crs=crs)
@@ -140,7 +139,7 @@ setMethod('raster', signature(x='character'),
 
 setMethod('raster', signature(x='BasicRaster'), 
 	function(x) {
-		r <- raster(x@extent, nrows=x@nrows, ncols=x@ncols, crs=x@crs)
+		r <- raster(x@extent, nrows=x@nrows, ncols=x@ncols, crs=.getCRS(x))
 		if (rotated(x)) {
 			r@rotated <- TRUE
 			r@rotation <- x@rotation
@@ -151,7 +150,7 @@ setMethod('raster', signature(x='BasicRaster'),
 
 setMethod('raster', signature(x='RasterLayer'), 
 	function(x) {
-		r <- raster(x@extent, nrows=x@nrows, ncols=x@ncols, crs=x@crs)
+		r <- raster(x@extent, nrows=x@nrows, ncols=x@ncols, crs=.getCRS(x))
 		r@rotated <- x@rotated
 		r@rotation <- x@rotation
 		r@file@blockrows <- x@file@blockrows
@@ -160,18 +159,6 @@ setMethod('raster', signature(x='RasterLayer'),
 	}
 )
 
-setMethod('raster', signature(x='RasterLayerSparse'), 
-	function(x) {
-		r <- raster(x@extent, nrows=x@nrows, ncols=x@ncols, crs=x@crs)
-		if (length(stats::na.omit(x@data@values)) > 0) {
-			v <- rep(NA, ncell(r))
-			v[x@index] <- x@data@values
-			setValues(r, v)
-		} else {
-			r
-		}
-	}
-)
 
 
 setMethod('raster', signature(x='RasterStack'), 
@@ -195,7 +182,7 @@ setMethod('raster', signature(x='RasterStack'),
 		} else {
 			r <- raster(extent(x))
 			dim(r) <- c(nrow(x), ncol(x))
-			projection(r) <- projection(x)
+			projection(r) <-.getCRS(x)
 		}
 		extent(r) <- extent(x) # perhaps it was changed by user and different on disk
 		if (rotated(x@layers[[1]])) {
@@ -232,7 +219,7 @@ setMethod('raster', signature(x='RasterBrick'),
 				# better raster(filename(x), band=dindex)  ?
 				# with zvar for ncdf files?
 				
-				r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=projection(x))	
+				r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=.getCRS(x))	
 				r@file <- x@file
 
 				r@file@blockrows <- x@file@blockrows
@@ -272,7 +259,7 @@ setMethod('raster', signature(x='RasterBrick'),
 				
 			} else {
 			
-				r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=projection(x))	
+				r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=.getCRS(x))	
 				if ( inMemory(x) ) {
 					if ( dindex != layer ) { warning(paste("layer was changed to", dindex)) }
 					r <- setValues(r, x@data@values[,dindex])
@@ -286,7 +273,7 @@ setMethod('raster', signature(x='RasterBrick'),
 			}
 			
 		} else {
-			r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=projection(x))	
+			r <- raster(extent(x), nrows=nrow(x), ncols=ncol(x), crs=.getCRS(x))	
 		}
 
 		if (rotated(x)) {
@@ -300,7 +287,8 @@ setMethod('raster', signature(x='RasterBrick'),
 
 
 setMethod('raster', signature(x='Extent'), 
-	function(x, nrows=10, ncols=10, crs=NA, ...) {
+	function(x, nrows=10, ncols=10, crs="", ...) {
+		crs <- .getCRS(crs)
 		raster(xmn=x@xmin, xmx=x@xmax, ymn=x@ymin, ymx=x@ymax, ncols=ncols, nrows=nrows, crs=crs, ...)
 	}
 )
@@ -308,8 +296,8 @@ setMethod('raster', signature(x='Extent'),
 
 setMethod('raster', signature(x='sf'), 
 	function(x, origin, ...){
-		x <- .sf2sp(x)
-		raster(x, origin, ...)
+		sp <- .sf2sp(x)
+		raster(sp, origin, ...)
 	}
 )
 
@@ -317,7 +305,7 @@ setMethod('raster', signature(x='sf'),
 setMethod('raster', signature(x='Spatial'), 
 	function(x, origin, ...){
 		r <- raster(extent(x), ...)
-		r@crs <- CRS(proj4string(x))
+		crs(r) <- .getCRS(x)
 		if (!missing(origin)) {
 			origin(r) <- origin
 			r <- extend(r, 1)
@@ -331,7 +319,7 @@ setMethod('raster', signature(x='Spatial'),
 setMethod('raster', signature(x='SpatialGrid'), 
 	function(x, layer=1, values=TRUE){
 		r <- raster(extent(x))
-		projection(r) <- CRS(proj4string(x))
+		projection(r) <-.getCRS(x)
 		dim(r) <- c(x@grid@cells.dim[2], x@grid@cells.dim[1])	
 		if (layer < 1) {
 			values <- FALSE
@@ -410,7 +398,7 @@ setMethod('raster', signature(x='kasc'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- "+proj=longlat +datum=WGS84"
+				crs <- CRS("+proj=longlat +datum=WGS84")
 			} else {
 				crs <- as.character(NA)
 			}
@@ -428,9 +416,9 @@ setMethod('raster', signature(x='asc'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- "+proj=longlat +datum=WGS84"
+				crs <- CRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- as.character(NA)
+				crs <- CRS(as.character(NA))
 			}
 		}
 		projection(x) <- crs
@@ -445,9 +433,9 @@ setMethod('raster', signature(x='kde'),
 		if (missing(crs)) {
 			e <- x@extent
 			if (e@xmin > -360.1 & e@xmax < 360.1 & e@ymin > -90.1 & e@ymax < 90.1) { 
-				crs <- "+proj=longlat +datum=WGS84"
+				crs <- CRS("+proj=longlat +datum=WGS84")
 			} else {
-				crs <- as.character(NA)
+				crs <- CRS(as.character(NA))
 			}
 		}
 		projection(x) <- crs
